==> jc-1.4.0.tar.gz: java/awt/ImageCapabilities.h <==
// public class java.awt.ImageCapabilities

// class file dependencies
// @dep_class d52942bbe01b598c java_awt_ImageCapabilities
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_ImageCapabilities_H_
#define _JC_java_awt_ImageCapabilities_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_ImageCapabilities$sub_refs	_jc_java_awt_ImageCapabilities$sub_refs;
typedef struct _jc_java_awt_ImageCapabilities$sub_nonrefs	_jc_java_awt_ImageCapabilities$sub_nonrefs;
typedef struct _jc_java_awt_ImageCapabilities$refs	_jc_java_awt_ImageCapabilities$refs;
typedef struct _jc_java_awt_ImageCapabilities$nonrefs	_jc_java_awt_ImageCapabilities$nonrefs;
typedef struct _jc_java_awt_ImageCapabilities$object	_jc_java_awt_ImageCapabilities$object;

typedef const struct _jc_java_awt_ImageCapabilities$vmethods	_jc_java_awt_ImageCapabilities$vmethods;
typedef const struct _jc_java_awt_ImageCapabilities$vtable	_jc_java_awt_ImageCapabilities$vtable;
typedef const struct _jc_java_awt_ImageCapabilities$vtype	_jc_java_awt_ImageCapabilities$vtype;

// Constructors
extern void _jc_java_awt_ImageCapabilities$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_java_awt_ImageCapabilities$object *, jboolean);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_ImageCapabilities$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_awt_ImageCapabilities$object *);
extern jboolean _jc_java_awt_ImageCapabilities$method$isAccelerated$8cc660304cb9ab95(_jc_env *, struct _jc_java_awt_ImageCapabilities$object *);
extern jboolean _jc_java_awt_ImageCapabilities$method$isTrueVolatile$58e9b12c691c1f23(_jc_env *, struct _jc_java_awt_ImageCapabilities$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_ImageCapabilities$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_awt_ImageCapabilities$method_info$isAccelerated$8cc660304cb9ab95;
extern _jc_method _jc_java_awt_ImageCapabilities$method_info$isTrueVolatile$58e9b12c691c1f23;

// Virtual methods structure
struct _jc_java_awt_ImageCapabilities$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_awt_ImageCapabilities$object *);
	jboolean	(*isAccelerated$8cc660304cb9ab95)(_jc_env *, struct _jc_java_awt_ImageCapabilities$object *);
	jboolean	(*isTrueVolatile$58e9b12c691c1f23)(_jc_env *, struct _jc_java_awt_ImageCapabilities$object *);
};

// Vtable
struct _jc_java_awt_ImageCapabilities$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_ImageCapabilities$vmethods	java_awt_ImageCapabilities;
};

// Vtype
struct _jc_java_awt_ImageCapabilities$vtype {
	_jc_type			type;
	_jc_java_awt_ImageCapabilities$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_ImageCapabilities$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_ImageCapabilities$refs {
    _jc_java_awt_ImageCapabilities$sub_refs	java_awt_ImageCapabilities;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_ImageCapabilities$sub_nonrefs {
	jboolean	accelerated;
};

// Non-reference instance fields (object)
struct _jc_java_awt_ImageCapabilities$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_ImageCapabilities$sub_nonrefs	java_awt_ImageCapabilities;
};

// Object instance structure
struct _jc_java_awt_ImageCapabilities$object {
	_jc_java_awt_ImageCapabilities$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_ImageCapabilities$vtype	*vtype;
	_jc_java_awt_ImageCapabilities$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_ImageCapabilities$vtype _jc_java_awt_ImageCapabilities$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_ImageCapabilities, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_ImageCapabilities$class_object;

#endif	/* _JC_java_awt_ImageCapabilities_H_ */

==> jc-1.4.5.tar.gz: java/awt/ImageCapabilities.h <==
// public class java.awt.ImageCapabilities

// class file dependencies
// @dep_class d52942bbe01b598c java_awt_ImageCapabilities
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_ImageCapabilities_H_
#define _JC_java_awt_ImageCapabilities_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_ImageCapabilities$sub_refs	_jc_java_awt_ImageCapabilities$sub_refs;
typedef struct _jc_java_awt_ImageCapabilities$sub_nonrefs	_jc_java_awt_ImageCapabilities$sub_nonrefs;
typedef struct _jc_java_awt_ImageCapabilities$refs	_jc_java_awt_ImageCapabilities$refs;
typedef struct _jc_java_awt_ImageCapabilities$nonrefs	_jc_java_awt_ImageCapabilities$nonrefs;
typedef struct _jc_java_awt_ImageCapabilities$object	_jc_java_awt_ImageCapabilities$object;

typedef const struct _jc_java_awt_ImageCapabilities$vmethods	_jc_java_awt_ImageCapabilities$vmethods;
typedef const struct _jc_java_awt_ImageCapabilities$vtable	_jc_java_awt_ImageCapabilities$vtable;
typedef const struct _jc_java_awt_ImageCapabilities$vtype	_jc_java_awt_ImageCapabilities$vtype;

// Constructors
extern void _jc_java_awt_ImageCapabilities$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_java_awt_ImageCapabilities$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_ImageCapabilities$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_awt_ImageCapabilities$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_ImageCapabilities$method$isAccelerated$8cc660304cb9ab95(_jc_env *, struct _jc_java_awt_ImageCapabilities$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_ImageCapabilities$method$isTrueVolatile$58e9b12c691c1f23(_jc_env *, struct _jc_java_awt_ImageCapabilities$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_ImageCapabilities$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_awt_ImageCapabilities$method_info$isAccelerated$8cc660304cb9ab95;
extern _jc_method _jc_java_awt_ImageCapabilities$method_info$isTrueVolatile$58e9b12c691c1f23;

// Virtual methods structure
struct _jc_java_awt_ImageCapabilities$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_awt_ImageCapabilities$object *) _JC_JCNI_ATTR;
	jboolean	(*isAccelerated$8cc660304cb9ab95)(_jc_env *, struct _jc_java_awt_ImageCapabilities$object *) _JC_JCNI_ATTR;
	jboolean	(*isTrueVolatile$58e9b12c691c1f23)(_jc_env *, struct _jc_java_awt_ImageCapabilities$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_ImageCapabilities$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_ImageCapabilities$vmethods	java_awt_ImageCapabilities;
};

// Vtype
struct _jc_java_awt_ImageCapabilities$vtype {
	_jc_type			type;
	_jc_java_awt_ImageCapabilities$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_ImageCapabilities$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_ImageCapabilities$refs {
    _jc_java_awt_ImageCapabilities$sub_refs	java_awt_ImageCapabilities;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_ImageCapabilities$sub_nonrefs {
	jboolean	accelerated;
};

// Non-reference instance fields (object)
struct _jc_java_awt_ImageCapabilities$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_ImageCapabilities$sub_nonrefs	java_awt_ImageCapabilities;
};

// Object instance structure
struct _jc_java_awt_ImageCapabilities$object {
	_jc_java_awt_ImageCapabilities$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_ImageCapabilities$vtype	*vtype;
	_jc_java_awt_ImageCapabilities$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_ImageCapabilities$vtype _jc_java_awt_ImageCapabilities$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_ImageCapabilities, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_ImageCapabilities$class_object;

#endif	/* _JC_java_awt_ImageCapabilities_H_ */
